diff --git a/src/java/com/threerings/miso/client/util/IsoUtil.java b/src/java/com/threerings/miso/client/util/IsoUtil.java
index 43ec235fb..6f147dcce 100644
--- a/src/java/com/threerings/miso/client/util/IsoUtil.java
+++ b/src/java/com/threerings/miso/client/util/IsoUtil.java
@@ -1,5 +1,5 @@
//
-// $Id: IsoUtil.java,v 1.33 2002/06/18 22:38:12 mdb Exp $
+// $Id: IsoUtil.java,v 1.34 2002/06/21 18:52:36 mdb Exp $
package com.threerings.miso.scene.util;
@@ -169,8 +169,10 @@ public class IsoUtil
// if the tile has an origin, use that, otherwise compute the
// origin based on the tile footprint
int tox = tile.getOriginX(), toy = tile.getOriginY();
- if (tox == -1 || toy == -1) {
+ if (tox == Integer.MIN_VALUE) {
tox = tile.getBaseWidth() * model.tilehwid;
+ }
+ if (toy == Integer.MIN_VALUE) {
toy = tile.getHeight();
}
diff --git a/src/java/com/threerings/media/tile/ObjectTile.java b/src/java/com/threerings/media/tile/ObjectTile.java
index d7cbaff21..c47b1dd2a 100644
--- a/src/java/com/threerings/media/tile/ObjectTile.java
+++ b/src/java/com/threerings/media/tile/ObjectTile.java
@@ -1,5 +1,5 @@
//
-// $Id: ObjectTile.java,v 1.9 2002/05/16 01:53:36 ray Exp $
+// $Id: ObjectTile.java,v 1.10 2002/06/21 18:52:36 mdb Exp $
package com.threerings.media.tile;
@@ -65,9 +65,10 @@ public class ObjectTile extends Tile
/**
* Returns the x offset into the tile image of the origin (which will
* be aligned with the bottom center of the origin tile) or -1 if the
* origin is not explicitly specified and should be computed from the
* image size and tile footprint.
*/
public int getOriginX ()
{
@@ -76,9 +77,10 @@ public class ObjectTile extends Tile
/**
* Returns the y offset into the tile image of the origin (which will
* be aligned with the bottom center of the origin tile) or -1 if the
* origin is not explicitly specified and should be computed from the
* image size and tile footprint.
*/
public int getOriginY ()
{
@@ -86,12 +88,12 @@ public class ObjectTile extends Tile
}
/**
- * Sets the offset in pixels to the origin in the tile image. The
- * object will be rendered such that its origin is at the bottom
- * center of its origin tile. If no origin is specified, the bottom of
- * the image is aligned with the bottom of the origin tile and the
- * left side of the image is aligned with the left edge of the
- * left-most base tile.
+ * Sets the offset in pixels from the origin of the tile image to the
+ * origin of the object. The object will be rendered such that its
+ * origin is at the bottom center of its origin tile. If no origin is
+ * specified, the bottom of the image is aligned with the bottom of
+ * the origin tile and the left side of the image is aligned with the
+ * left edge of the left-most base tile.
*/
public void setOrigin (int x, int y)
{
@@ -128,11 +130,13 @@ public class ObjectTile extends Tile
/** The object footprint height in unit tile units. */
protected int _baseHeight = 1;
- /** The x offset into the tile image of the origin or -1 if the origin
- * should be calculated based on the footprint. */
- protected int _originX = -1;
+ /** The x offset from the origin of the tile image to the object's
+ * origin or MIN_VALUE if the origin should be calculated based on the
+ * footprint. */
+ protected int _originX = Integer.MIN_VALUE;
- /** The y offset into the tile image of the origin or -1 if the origin
- * should be calculated based on the footprint. */
- protected int _originY = -1;
+ /** The y offset from the origin of the tile image to the object's
+ * origin or MIN_VALUE if the origin should be calculated based on the
+ * footprint. */
+ protected int _originY = Integer.MIN_VALUE;
}
@@ -65,9 +65,10 @@ public class ObjectTile extends Tile
/**
* Returns the x offset into the tile image of the origin (which will
- * be aligned with the bottom center of the origin tile) or -1 if the
- * origin is not explicitly specified and should be computed from the
- * image size and tile footprint.
+ * be aligned with the bottom center of the origin tile) or
+ * Integer.MIN_VALUE if the origin is not explicitly
+ * specified and should be computed from the image size and tile
+ * footprint.
*/
public int getOriginX ()
@@ -76,9 +77,10 @@ public class ObjectTile extends Tile
/**
* Returns the y offset into the tile image of the origin (which will
- * be aligned with the bottom center of the origin tile) or -1 if the
- * origin is not explicitly specified and should be computed from the
- * image size and tile footprint.
+ * be aligned with the bottom center of the origin tile) or
+ * Integer.MIN_VALUE if the origin is not explicitly
+ * specified and should be computed from the image size and tile
+ * footprint.
*/
public int getOriginY ()